[gnome-builder] typo: fix various DBus -> D-Bus usage



commit 6171a324948e8bb50bb02ac99f1fbb6e0200d6de
Author: Christian Hergert <chergert redhat com>
Date:   Wed Apr 24 10:36:46 2019 -0700

    typo: fix various DBus -> D-Bus usage

 src/libide/gui/ide-application.c              | 4 ++--
 src/libide/gui/ide-worker-manager.c           | 4 ++--
 src/libide/threading/ide-flatpak-subprocess.c | 6 +++---
 src/plugins/dspy/libdspy/dspy-name.c          | 2 +-
 4 files changed, 8 insertions(+), 8 deletions(-)
---
diff --git a/src/libide/gui/ide-worker-manager.c b/src/libide/gui/ide-worker-manager.c
index aef90a2dc..1ecc6e179 100644
--- a/src/libide/gui/ide-worker-manager.c
+++ b/src/libide/gui/ide-worker-manager.c
@@ -107,7 +107,7 @@ ide_worker_manager_constructed (GObject *object)
 
       if (tmpdir == NULL)
         {
-          g_error ("Failed to determine temporary directory for DBus.");
+          g_error ("Failed to determine temporary directory for D-Bus.");
           exit (EXIT_FAILURE);
         }
 
@@ -135,7 +135,7 @@ ide_worker_manager_constructed (GObject *object)
                            self,
                            G_CONNECT_SWAPPED);
 
-  IDE_TRACE_MSG ("GDBusServer listening at %s", address);
+  IDE_TRACE_MSG ("D-Bus Server listening at %s", address);
 
   g_dbus_server_start (self->dbus_server);
 
diff --git a/src/plugins/dspy/libdspy/dspy-name.c b/src/plugins/dspy/libdspy/dspy-name.c
index 2b0489dc6..4d3d61739 100644
--- a/src/plugins/dspy/libdspy/dspy-name.c
+++ b/src/plugins/dspy/libdspy/dspy-name.c
@@ -159,7 +159,7 @@ dspy_name_class_init (DspyNameClass *klass)
   properties [PROP_OWNER] =
     g_param_spec_string ("owner",
                          "Owner",
-                         "The owner of the DBus name",
+                         "The owner of the D-Bus name",
                          NULL,
                          (G_PARAM_READABLE | G_PARAM_STATIC_STRINGS));
 


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/libide/gui/ide-application.c b/src/libide/gui/ide-application.c
index b0c6a7914..ac1b8233f 100644
--- a/src/libide/gui/ide-application.c
+++ b/src/libide/gui/ide-application.c
@@ -129,7 +129,7 @@ ide_application_startup (GApplication *app)
 
   /*
    * We require a desktop session that provides a properly working
    * DBus environment. Bail if for some reason that is not the case.
    */
   if (g_getenv ("DBUS_SESSION_BUS_ADDRESS") == NULL)
     g_error ("%s",
@@ -220,7 +220,7 @@ ide_application_activate_worker (IdeApplication *self)
 
   if (error != NULL)
     {
-      g_error ("DBus failure: %s", error->message);
+      g_error ("D-Bus failure: %s", error->message);
       IDE_EXIT;
     }
 
@@ -129,7 +129,7 @@ ide_application_startup (GApplication *app)
   /*
    * We require a desktop session that provides a properly working
-   * DBus environment. Bail if for some reason that is not the case.
+   * D-Bus environment. Bail if for some reason that is not the case.
    */
   if (g_getenv ("DBUS_SESSION_BUS_ADDRESS") == NULL)
diff --git a/src/libide/threading/ide-flatpak-subprocess.c b/src/libide/threading/ide-flatpak-subprocess.c
index f22bd5dfc..241c91a74 100644
--- a/src/libide/threading/ide-flatpak-subprocess.c
+++ b/src/libide/threading/ide-flatpak-subprocess.c
@@ -1114,7 +1114,7 @@ host_command_exited_cb (GDBusConnection *connection,
   /* We can release our dbus signal handler now */
   if (self->exited_subscription != 0)
     {
-      IDE_TRACE_MSG ("Unsubscribing from DBus subscription %d", self->exited_subscription);
+      IDE_TRACE_MSG ("Unsubscribing from D-Bus subscription %d", self->exited_subscription);
       g_dbus_connection_signal_unsubscribe (self->connection, self->exited_subscription);
       self->exited_subscription = 0;
     }
@@ -1424,7 +1424,7 @@ ide_flatpak_subprocess_initable_init (GInitable     *initable,
 
   /*
    * Make sure we've closed or stolen all of the FDs that are in play
    * before calling the DBus service.
    */
   g_assert_cmpint (-1, ==, stdin_pair[0]);
   g_assert_cmpint (-1, ==, stdin_pair[1]);
@@ -1558,7 +1558,7 @@ ide_flatpak_subprocess_dispose (GObject *object)
     {
       if (self->connection != NULL && !g_dbus_connection_is_closed (self->connection))
         {
-          IDE_TRACE_MSG ("Unsubscribing from DBus subscription %d", self->exited_subscription);
+          IDE_TRACE_MSG ("Unsubscribing from D-Bus subscription %d", self->exited_subscription);
           g_dbus_connection_signal_unsubscribe (self->connection, self->exited_subscription);
         }
 
@@ -1424,7 +1424,7 @@ ide_flatpak_subprocess_initable_init (GInitable     *initable,
   /*
    * Make sure we've closed or stolen all of the FDs that are in play
-   * before calling the DBus service.
+   * before calling the D-Bus service.
    */
   g_assert_cmpint (-1, ==, stdin_pair[0]);